==> haskell-hls-explicit-record-fields-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.1.0.0-6nDVbTabfSUG1XbfnTX6Iu

key:
    hls-explicit-record-fields-plugin-2.1.0.0-6nDVbTabfSUG1XbfnTX6Iu

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  90b0eff0b9c945e187bfe938247b83f1
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-record-fields-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.1.0.0-6nDVbTabfSUG1XbfnTX6Iu

depends:
    base-4.18.2.1 containers-0.6.7 ghc-boot-th-9.6.6
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-graph-2.1.0.0-2K7OAPbw31L8NzoSrWGIDe
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-record-fields-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.1.0.0-CryxyYu4p1F7REx8EvSCo4

key:
    hls-explicit-record-fields-plugin-2.1.0.0-CryxyYu4p1F7REx8EvSCo4

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  382d6e73a1bbddd1ffc051263300a61b
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-record-fields-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.1.0.0-CryxyYu4p1F7REx8EvSCo4

depends:
    base-4.18.2.1 containers-0.6.7 ghc-boot-th-9.6.6
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-graph-2.1.0.0-LgEicARMXCt6QmF6Vp3LRx
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    syb-0.7.3-MvqtDDcT2PHyhdKWhEKAp text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
